==> kdebindings-2.2.2.tar.bz2: kdebindings-2.2.2/qtjava/javalib/org/kde/qt/QCanvasViewEventHandling.java <==
package org.kde.qt;


/** Override these methods in subclasses of {@link QCanvasView} to customise event handling behaviour */
public interface QCanvasViewEventHandling {
	void keyPressEvent(QKeyEvent arg1);
	void keyReleaseEvent(QKeyEvent arg1);
	void focusOutEvent(QFocusEvent arg1);
	void childEvent(QChildEvent arg1);
	void viewportDragMoveEvent(QDragMoveEvent arg1);
	void dragMoveEvent(QDragMoveEvent arg1);
	void contentsWheelEvent(QWheelEvent arg1);
	void leaveEvent(QEvent arg1);
	void showEvent(QShowEvent arg1);
	void viewportMousePressEvent(QMouseEvent arg1);
	void mousePressEvent(QMouseEvent arg1);
	void customEvent(QCustomEvent arg1);
	void viewportMouseReleaseEvent(QMouseEvent arg1);
	void mouseReleaseEvent(QMouseEvent arg1);
	void viewportMouseDoubleClickEvent(QMouseEvent arg1);
	void mouseDoubleClickEvent(QMouseEvent arg1);
	void viewportDragLeaveEvent(QDragLeaveEvent arg1);
	void dragLeaveEvent(QDragLeaveEvent arg1);
	void enterEvent(QEvent arg1);
	void contentsDropEvent(QDropEvent arg1);
	void focusInEvent(QFocusEvent arg1);
	void contentsDragLeaveEvent(QDragLeaveEvent arg1);
	void viewportDropEvent(QDropEvent arg1);
	void dropEvent(QDropEvent arg1);
	void contentsMouseDoubleClickEvent(QMouseEvent arg1);
	void viewportDragEnterEvent(QDragEnterEvent arg1);
	void dragEnterEvent(QDragEnterEvent arg1);
	void viewportMouseMoveEvent(QMouseEvent arg1);
	void mouseMoveEvent(QMouseEvent arg1);
	void contentsDragMoveEvent(QDragMoveEvent arg1);
	void moveEvent(QMoveEvent arg1);
	void contentsMouseReleaseEvent(QMouseEvent arg1);
	void viewportWheelEvent(QWheelEvent arg1);
	void wheelEvent(QWheelEvent arg1);
	void hideEvent(QHideEvent arg1);
	void contentsDragEnterEvent(QDragEnterEvent arg1);
	void contentsMouseMoveEvent(QMouseEvent arg1);
	void contentsMousePressEvent(QMouseEvent arg1);
	void closeEvent(QCloseEvent arg1);
	void viewportPaintEvent(QPaintEvent arg1);
	void paintEvent(QPaintEvent arg1);
	void timerEvent(QTimerEvent arg1);
	void viewportResizeEvent(QResizeEvent arg1);
	void resizeEvent(QResizeEvent arg1);
}

==> kdebindings-3.0.1.tar.bz2: kdebindings-3.0.1/qtjava/javalib/org/kde/qt/QCanvasViewEventHandling.java <==
package org.kde.qt;


/** Override these methods in subclasses of {@link QCanvasView} to customise event handling behaviour */
public interface QCanvasViewEventHandling {
	void enterEvent(QEvent arg1);
	void contentsDropEvent(QDropEvent arg1);
	void focusInEvent(QFocusEvent arg1);
	void imEndEvent(QIMEvent arg1);
	void keyPressEvent(QKeyEvent arg1);
	void contentsDragLeaveEvent(QDragLeaveEvent arg1);
	void keyReleaseEvent(QKeyEvent arg1);
	void viewportDropEvent(QDropEvent arg1);
	void dropEvent(QDropEvent arg1);
	void contentsMouseDoubleClickEvent(QMouseEvent arg1);
	void focusOutEvent(QFocusEvent arg1);
	void childEvent(QChildEvent arg1);
	void viewportDragMoveEvent(QDragMoveEvent arg1);
	void dragMoveEvent(QDragMoveEvent arg1);
	void contentsWheelEvent(QWheelEvent arg1);
	void leaveEvent(QEvent arg1);
	void viewportDragEnterEvent(QDragEnterEvent arg1);
	void dragEnterEvent(QDragEnterEvent arg1);
	void tabletEvent(QTabletEvent arg1);
	void viewportMouseMoveEvent(QMouseEvent arg1);
	void mouseMoveEvent(QMouseEvent arg1);
	void showEvent(QShowEvent arg1);
	void contentsDragMoveEvent(QDragMoveEvent arg1);
	void contentsContextMenuEvent(QContextMenuEvent arg1);
	void moveEvent(QMoveEvent arg1);
	void contentsMouseReleaseEvent(QMouseEvent arg1);
	void viewportWheelEvent(QWheelEvent arg1);
	void wheelEvent(QWheelEvent arg1);
	void viewportContextMenuEvent(QContextMenuEvent arg1);
	void hideEvent(QHideEvent arg1);
	void contextMenuEvent(QContextMenuEvent arg1);
	void contentsDragEnterEvent(QDragEnterEvent arg1);
	void contentsMouseMoveEvent(QMouseEvent arg1);
	void viewportMousePressEvent(QMouseEvent arg1);
	void mousePressEvent(QMouseEvent arg1);
	void contentsMousePressEvent(QMouseEvent arg1);
	void imStartEvent(QIMEvent arg1);
	void imComposeEvent(QIMEvent arg1);
	void customEvent(QCustomEvent arg1);
	void viewportMouseReleaseEvent(QMouseEvent arg1);
	void mouseReleaseEvent(QMouseEvent arg1);
	void closeEvent(QCloseEvent arg1);
	void viewportPaintEvent(QPaintEvent arg1);
	void paintEvent(QPaintEvent arg1);
	void timerEvent(QTimerEvent arg1);
	void viewportMouseDoubleClickEvent(QMouseEvent arg1);
	void mouseDoubleClickEvent(QMouseEvent arg1);
	void viewportDragLeaveEvent(QDragLeaveEvent arg1);
	void dragLeaveEvent(QDragLeaveEvent arg1);
	void viewportResizeEvent(QResizeEvent arg1);
	void resizeEvent(QResizeEvent arg1);
}
